Module: Aws::S3Tables

Defined in:
lib/aws-sdk-s3tables/endpoint_parameters.rb,
lib/aws-sdk-s3tables/plugins/endpoints.rb,
lib/aws-sdk-s3tables/endpoint_provider.rb,
lib/aws-sdk-s3tables/client_api.rb,
lib/aws-sdk-s3tables/endpoints.rb,
lib/aws-sdk-s3tables/resource.rb,
lib/aws-sdk-s3tables/waiters.rb,
lib/aws-sdk-s3tables/errors.rb,
lib/aws-sdk-s3tables/client.rb,
lib/aws-sdk-s3tables/types.rb,
lib/aws-sdk-s3tables.rb

Overview

This module provides support for Amazon S3 Tables. This module is available in the ‘aws-sdk-s3tables` gem.

# Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

s3_tables = Aws::S3Tables::Client.new
resp = s3_tables.create_namespace(params)

See Client for more information.

# Errors

Errors returned from Amazon S3 Tables are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::S3Tables::Errors::ServiceError
  # rescues all Amazon S3 Tables API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource

service collapse

GEM_VERSION =
'1.30.0'