Class: Aws::S3Tables::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::S3Tables::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-s3tables/client.rb,
sig/client.rbs
Overview
An API client for S3Tables. To construct a client, you need to configure a :region and :credentials.
client = Aws::S3Tables::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateNamespaceResponseSuccess, _CreateTableBucketResponseSuccess, _CreateTableResponseSuccess, _GetNamespaceResponseSuccess, _GetTableBucketEncryptionResponseSuccess, _GetTableBucketMaintenanceConfigurationResponseSuccess, _GetTableBucketMetricsConfigurationResponseSuccess, _GetTableBucketPolicyResponseSuccess, _GetTableBucketReplicationResponseSuccess, _GetTableBucketResponseSuccess, _GetTableBucketStorageClassResponseSuccess, _GetTableEncryptionResponseSuccess, _GetTableMaintenanceConfigurationResponseSuccess, _GetTableMaintenanceJobStatusResponseSuccess, _GetTableMetadataLocationResponseSuccess, _GetTablePolicyResponseSuccess, _GetTableRecordExpirationConfigurationResponseSuccess, _GetTableRecordExpirationJobStatusResponseSuccess, _GetTableReplicationResponseSuccess, _GetTableReplicationStatusResponseSuccess, _GetTableResponseSuccess, _GetTableStorageClassResponseSuccess, _ListNamespacesResponseSuccess, _ListTableBucketsResponseSuccess, _ListTablesResponseSuccess, _ListTagsForResourceResponseSuccess, _PutTableBucketReplicationResponseSuccess, _PutTableReplicationResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateTableMetadataLocationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_namespace(params = {}) ⇒ Types::CreateNamespaceResponse
Creates a namespace.
-
#create_table(params = {}) ⇒ Types::CreateTableResponse
Creates a new table associated with the given namespace in a table bucket.
-
#create_table_bucket(params = {}) ⇒ Types::CreateTableBucketResponse
Creates a table bucket.
-
#delete_namespace(params = {}) ⇒ Struct
Deletes a namespace.
-
#delete_table(params = {}) ⇒ Struct
Deletes a table.
-
#delete_table_bucket(params = {}) ⇒ Struct
Deletes a table bucket.
-
#delete_table_bucket_encryption(params = {}) ⇒ Struct
Deletes the encryption configuration for a table bucket.
-
#delete_table_bucket_metrics_configuration(params = {}) ⇒ Struct
Deletes the metrics configuration for a table bucket.
-
#delete_table_bucket_policy(params = {}) ⇒ Struct
Deletes a table bucket policy.
-
#delete_table_bucket_replication(params = {}) ⇒ Struct
Deletes the replication configuration for a table bucket.
-
#delete_table_policy(params = {}) ⇒ Struct
Deletes a table policy.
-
#delete_table_replication(params = {}) ⇒ Struct
Deletes the replication configuration for a specific table.
-
#get_namespace(params = {}) ⇒ Types::GetNamespaceResponse
Gets details about a namespace.
-
#get_table(params = {}) ⇒ Types::GetTableResponse
Gets details about a table.
-
#get_table_bucket(params = {}) ⇒ Types::GetTableBucketResponse
Gets details on a table bucket.
-
#get_table_bucket_encryption(params = {}) ⇒ Types::GetTableBucketEncryptionResponse
Gets the encryption configuration for a table bucket.
-
#get_table_bucket_maintenance_configuration(params = {}) ⇒ Types::GetTableBucketMaintenanceConfigurationResponse
Gets details about a maintenance configuration for a given table bucket.
-
#get_table_bucket_metrics_configuration(params = {}) ⇒ Types::GetTableBucketMetricsConfigurationResponse
Gets the metrics configuration for a table bucket.
-
#get_table_bucket_policy(params = {}) ⇒ Types::GetTableBucketPolicyResponse
Gets details about a table bucket policy.
-
#get_table_bucket_replication(params = {}) ⇒ Types::GetTableBucketReplicationResponse
Retrieves the replication configuration for a table bucket.This operation returns the IAM role,
versionToken, and replication rules that define how tables in this bucket are replicated to other buckets. -
#get_table_bucket_storage_class(params = {}) ⇒ Types::GetTableBucketStorageClassResponse
Retrieves the storage class configuration for a specific table.
-
#get_table_encryption(params = {}) ⇒ Types::GetTableEncryptionResponse
Gets the encryption configuration for a table.
-
#get_table_maintenance_configuration(params = {}) ⇒ Types::GetTableMaintenanceConfigurationResponse
Gets details about the maintenance configuration of a table.
-
#get_table_maintenance_job_status(params = {}) ⇒ Types::GetTableMaintenanceJobStatusResponse
Gets the status of a maintenance job for a table.
-
#get_table_metadata_location(params = {}) ⇒ Types::GetTableMetadataLocationResponse
Gets the location of the table metadata.
-
#get_table_policy(params = {}) ⇒ Types::GetTablePolicyResponse
Gets details about a table policy.
-
#get_table_record_expiration_configuration(params = {}) ⇒ Types::GetTableRecordExpirationConfigurationResponse
Retrieves the expiration configuration settings for records in a table, and the status of the configuration.
-
#get_table_record_expiration_job_status(params = {}) ⇒ Types::GetTableRecordExpirationJobStatusResponse
Retrieves the status, metrics, and details of the latest record expiration job for a table.
-
#get_table_replication(params = {}) ⇒ Types::GetTableReplicationResponse
Retrieves the replication configuration for a specific table.
-
#get_table_replication_status(params = {}) ⇒ Types::GetTableReplicationStatusResponse
Retrieves the replication status for a table, including the status of replication to each destination.
-
#get_table_storage_class(params = {}) ⇒ Types::GetTableStorageClassResponse
Retrieves the storage class configuration for a specific table.
-
#list_namespaces(params = {}) ⇒ Types::ListNamespacesResponse
Lists the namespaces within a table bucket.
-
#list_table_buckets(params = {}) ⇒ Types::ListTableBucketsResponse
Lists table buckets for your account.
-
#list_tables(params = {}) ⇒ Types::ListTablesResponse
List tables in the given table bucket.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags applied to a specified Amazon S3 Tables resource.
-
#put_table_bucket_encryption(params = {}) ⇒ Struct
Sets the encryption configuration for a table bucket.
-
#put_table_bucket_maintenance_configuration(params = {}) ⇒ Struct
Creates a new maintenance configuration or replaces an existing maintenance configuration for a table bucket.
-
#put_table_bucket_metrics_configuration(params = {}) ⇒ Struct
Sets the metrics configuration for a table bucket.
-
#put_table_bucket_policy(params = {}) ⇒ Struct
Creates a new table bucket policy or replaces an existing table bucket policy for a table bucket.
-
#put_table_bucket_replication(params = {}) ⇒ Types::PutTableBucketReplicationResponse
Creates or updates the replication configuration for a table bucket.
-
#put_table_bucket_storage_class(params = {}) ⇒ Struct
Sets or updates the storage class configuration for a table bucket.
-
#put_table_maintenance_configuration(params = {}) ⇒ Struct
Creates a new maintenance configuration or replaces an existing maintenance configuration for a table.
-
#put_table_policy(params = {}) ⇒ Struct
Creates a new table policy or replaces an existing table policy for a table.
-
#put_table_record_expiration_configuration(params = {}) ⇒ Struct
Creates or updates the expiration configuration settings for records in a table, including the status of the configuration.
-
#put_table_replication(params = {}) ⇒ Types::PutTableReplicationResponse
Creates or updates the replication configuration for a specific table.
-
#rename_table(params = {}) ⇒ Struct
Renames a table or a namespace.
-
#tag_resource(params = {}) ⇒ Struct
Applies one or more user-defined tags to an Amazon S3 Tables resource or updates existing tags.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified user-defined tags from an Amazon S3 Tables resource.
-
#update_table_metadata_location(params = {}) ⇒ Types::UpdateTableMetadataLocationResponse
Updates the metadata location for a table.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-s3tables/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2990 2991 2992 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2990 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2993 2994 2995 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2993 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2963 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::S3Tables') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-s3tables' context[:gem_version] = '1.33.0' Seahorse::Client::Request.new(handlers, context) end |
#create_namespace(params = {}) ⇒ Types::CreateNamespaceResponse
Creates a namespace. A namespace is a logical grouping of tables within your table bucket, which you can use to organize tables. For more information, see Create a namespace in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:CreateNamespace permission to use this
operation.
87 |
# File 'sig/client.rbs', line 87
def create_namespace: (
|
#create_table(params = {}) ⇒ Types::CreateTableResponse
Creates a new table associated with the given namespace in a table bucket. For more information, see Creating an Amazon S3 table in the Amazon Simple Storage Service User Guide.
Permissions
: * You must have the s3tables:CreateTable permission to use this
operation.
* If you use this operation with the optional `metadata` request
parameter you must have the `s3tables:PutTableData` permission.
* If you use this operation with the optional
`encryptionConfiguration` request parameter you must have the
`s3tables:PutTableEncryption` permission.
* If you use this operation with the `storageClassConfiguration`
request parameter, you must have the
`s3tables:PutTableStorageClass` permission.
* To create a table with tags, you must have the
`s3tables:TagResource` permission in addition to
`s3tables:CreateTable` permission.
<note markdown="1"> Additionally, If you choose SSE-KMS encryption you must grant the S3
Tables maintenance principal access to your KMS key. For more
information, see [Permissions requirements for S3 Tables SSE-KMS
encryption][2].
99 |
# File 'sig/client.rbs', line 99
def create_table: (
|
#create_table_bucket(params = {}) ⇒ Types::CreateTableBucketResponse
Creates a table bucket. For more information, see Creating a table bucket in the Amazon Simple Storage Service User Guide.
Permissions
: * You must have the s3tables:CreateTableBucket permission to use
this operation.
* If you use this operation with the optional
`encryptionConfiguration` parameter you must have the
`s3tables:PutTableBucketEncryption` permission.
* If you use this operation with the `storageClassConfiguration`
request parameter, you must have the
`s3tables:PutTableBucketStorageClass` permission.
* To create a table bucket with tags, you must have the
`s3tables:TagResource` permission in addition to
`s3tables:CreateTableBucket` permission.
172 |
# File 'sig/client.rbs', line 172
def create_table_bucket: (
|
#delete_namespace(params = {}) ⇒ Struct
Deletes a namespace. For more information, see Delete a namespace in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:DeleteNamespace permission to use this
operation.
186 |
# File 'sig/client.rbs', line 186
def delete_namespace: (
|
#delete_table(params = {}) ⇒ Struct
Deletes a table. For more information, see Deleting an Amazon S3 table in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:DeleteTable permission to use this
operation.
193 |
# File 'sig/client.rbs', line 193
def delete_table: (
|
#delete_table_bucket(params = {}) ⇒ Struct
Deletes a table bucket. For more information, see Deleting a table bucket in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:DeleteTableBucket permission to use
this operation.
202 |
# File 'sig/client.rbs', line 202
def delete_table_bucket: (
|
#delete_table_bucket_encryption(params = {}) ⇒ Struct
Deletes the encryption configuration for a table bucket.
Permissions
: You must have the s3tables:DeleteTableBucketEncryption permission
to use this operation.
208 |
# File 'sig/client.rbs', line 208
def delete_table_bucket_encryption: (
|
#delete_table_bucket_metrics_configuration(params = {}) ⇒ Struct
Deletes the metrics configuration for a table bucket.
Permissions
: You must have the s3tables:DeleteTableBucketMetricsConfiguration
permission to use this operation.
214 |
# File 'sig/client.rbs', line 214
def delete_table_bucket_metrics_configuration: (
|
#delete_table_bucket_policy(params = {}) ⇒ Struct
Deletes a table bucket policy. For more information, see Deleting a table bucket policy in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:DeleteTableBucketPolicy permission to
use this operation.
220 |
# File 'sig/client.rbs', line 220
def delete_table_bucket_policy: (
|
#delete_table_bucket_replication(params = {}) ⇒ Struct
Deletes the replication configuration for a table bucket. After deletion, new table updates will no longer be replicated to destination buckets, though existing replicated tables will remain in destination buckets.
Permissions
: You must have the s3tables:DeleteTableBucketReplication permission
to use this operation.
226 |
# File 'sig/client.rbs', line 226
def delete_table_bucket_replication: (
|
#delete_table_policy(params = {}) ⇒ Struct
Deletes a table policy. For more information, see Deleting a table policy in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:DeleteTablePolicy permission to use
this operation.
233 |
# File 'sig/client.rbs', line 233
def delete_table_policy: (
|
#delete_table_replication(params = {}) ⇒ Struct
Deletes the replication configuration for a specific table. After deletion, new updates to this table will no longer be replicated to destination tables, though existing replicated copies will remain in destination buckets.
Permissions
: You must have the s3tables:DeleteTableReplication permission to
use this operation.
241 |
# File 'sig/client.rbs', line 241
def delete_table_replication: (
|
#get_namespace(params = {}) ⇒ Types::GetNamespaceResponse
Gets details about a namespace. For more information, see Table namespaces in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:GetNamespace permission to use this
operation.
257 |
# File 'sig/client.rbs', line 257
def get_namespace: (
|
#get_table(params = {}) ⇒ Types::GetTableResponse
Gets details about a table. For more information, see S3 Tables in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:GetTable permission to use this
operation.
284 |
# File 'sig/client.rbs', line 284
def get_table: (
|
#get_table_bucket(params = {}) ⇒ Types::GetTableBucketResponse
Gets details on a table bucket. For more information, see Viewing details about an Amazon S3 table bucket in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:GetTableBucket permission to use this
operation.
302 |
# File 'sig/client.rbs', line 302
def get_table_bucket: (
|
#get_table_bucket_encryption(params = {}) ⇒ Types::GetTableBucketEncryptionResponse
Gets the encryption configuration for a table bucket.
Permissions
: You must have the s3tables:GetTableBucketEncryption permission to
use this operation.
312 |
# File 'sig/client.rbs', line 312
def get_table_bucket_encryption: (
|
#get_table_bucket_maintenance_configuration(params = {}) ⇒ Types::GetTableBucketMaintenanceConfigurationResponse
Gets details about a maintenance configuration for a given table bucket. For more information, see Amazon S3 table bucket maintenance in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:GetTableBucketMaintenanceConfiguration
permission to use this operation.
323 |
# File 'sig/client.rbs', line 323
def get_table_bucket_maintenance_configuration: (
|
#get_table_bucket_metrics_configuration(params = {}) ⇒ Types::GetTableBucketMetricsConfigurationResponse
Gets the metrics configuration for a table bucket.
Permissions
: You must have the s3tables:GetTableBucketMetricsConfiguration
permission to use this operation.
334 |
# File 'sig/client.rbs', line 334
def get_table_bucket_metrics_configuration: (
|
#get_table_bucket_policy(params = {}) ⇒ Types::GetTableBucketPolicyResponse
Gets details about a table bucket policy. For more information, see Viewing a table bucket policy in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:GetTableBucketPolicy permission to use
this operation.
344 |
# File 'sig/client.rbs', line 344
def get_table_bucket_policy: (
|
#get_table_bucket_replication(params = {}) ⇒ Types::GetTableBucketReplicationResponse
Retrieves the replication configuration for a table bucket.This
operation returns the IAM role, versionToken, and replication rules
that define how tables in this bucket are replicated to other buckets.
Permissions
: You must have the s3tables:GetTableBucketReplication permission to
use this operation.
355 |
# File 'sig/client.rbs', line 355
def get_table_bucket_replication: (
|
#get_table_bucket_storage_class(params = {}) ⇒ Types::GetTableBucketStorageClassResponse
Retrieves the storage class configuration for a specific table. This allows you to view the storage class settings that apply to an individual table, which may differ from the table bucket's default configuration.
Permissions
: You must have the s3tables:GetTableBucketStorageClass permission
to use this operation.
365 |
# File 'sig/client.rbs', line 365
def get_table_bucket_storage_class: (
|
#get_table_encryption(params = {}) ⇒ Types::GetTableEncryptionResponse
Gets the encryption configuration for a table.
Permissions
: You must have the s3tables:GetTableEncryption permission to use
this operation.
375 |
# File 'sig/client.rbs', line 375
def get_table_encryption: (
|
#get_table_maintenance_configuration(params = {}) ⇒ Types::GetTableMaintenanceConfigurationResponse
Gets details about the maintenance configuration of a table. For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.
Permissions
: * You must have the s3tables:GetTableMaintenanceConfiguration
permission to use this operation.
* You must have the `s3tables:GetTableData` permission to use set
the compaction strategy to `sort` or `zorder`.
388 |
# File 'sig/client.rbs', line 388
def get_table_maintenance_configuration: (
|
#get_table_maintenance_job_status(params = {}) ⇒ Types::GetTableMaintenanceJobStatusResponse
Gets the status of a maintenance job for a table. For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:GetTableMaintenanceJobStatus permission
to use this operation.
401 |
# File 'sig/client.rbs', line 401
def get_table_maintenance_job_status: (
|
#get_table_metadata_location(params = {}) ⇒ Types::GetTableMetadataLocationResponse
Gets the location of the table metadata.
Permissions
: You must have the s3tables:GetTableMetadataLocation permission to
use this operation.
415 |
# File 'sig/client.rbs', line 415
def get_table_metadata_location: (
|
#get_table_policy(params = {}) ⇒ Types::GetTablePolicyResponse
Gets details about a table policy. For more information, see Viewing a table policy in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:GetTablePolicy permission to use this
operation.
427 |
# File 'sig/client.rbs', line 427
def get_table_policy: (
|
#get_table_record_expiration_configuration(params = {}) ⇒ Types::GetTableRecordExpirationConfigurationResponse
Retrieves the expiration configuration settings for records in a
table, and the status of the configuration. If the status of the
configuration is enabled, records expire and are automatically
removed from the table after the specified number of days.
Permissions
: You must have the s3tables:GetTableRecordExpirationConfiguration
permission to use this operation.
439 |
# File 'sig/client.rbs', line 439
def get_table_record_expiration_configuration: (
|
#get_table_record_expiration_job_status(params = {}) ⇒ Types::GetTableRecordExpirationJobStatusResponse
Retrieves the status, metrics, and details of the latest record expiration job for a table. This includes when the job ran, and whether it succeeded or failed. If the job ran successfully, this also includes statistics about the records that were removed.
Permissions
: You must have the s3tables:GetTableRecordExpirationJobStatus
permission to use this operation.
452 |
# File 'sig/client.rbs', line 452
def get_table_record_expiration_job_status: (
|
#get_table_replication(params = {}) ⇒ Types::GetTableReplicationResponse
Retrieves the replication configuration for a specific table.
Permissions
: You must have the s3tables:GetTableReplication permission to use
this operation.
463 |
# File 'sig/client.rbs', line 463
def get_table_replication: (
|
#get_table_replication_status(params = {}) ⇒ Types::GetTableReplicationStatusResponse
Retrieves the replication status for a table, including the status of replication to each destination. This operation provides visibility into replication health and progress.
Permissions
: You must have the s3tables:GetTableReplicationStatus permission to
use this operation.
474 |
# File 'sig/client.rbs', line 474
def get_table_replication_status: (
|
#get_table_storage_class(params = {}) ⇒ Types::GetTableStorageClassResponse
Retrieves the storage class configuration for a specific table. This allows you to view the storage class settings that apply to an individual table, which may differ from the table bucket's default configuration.
Permissions
: You must have the s3tables:GetTableStorageClass permission to use
this operation.
484 |
# File 'sig/client.rbs', line 484
def get_table_storage_class: (
|
#list_namespaces(params = {}) ⇒ Types::ListNamespacesResponse
Lists the namespaces within a table bucket. For more information, see Table namespaces in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:ListNamespaces permission to use this
operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
497 |
# File 'sig/client.rbs', line 497
def list_namespaces: (
|
#list_table_buckets(params = {}) ⇒ Types::ListTableBucketsResponse
Lists table buckets for your account. For more information, see S3 Table buckets in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:ListTableBuckets permission to use this
operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
511 |
# File 'sig/client.rbs', line 511
def list_table_buckets: (
|
#list_tables(params = {}) ⇒ Types::ListTablesResponse
List tables in the given table bucket. For more information, see S3 Tables in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:ListTables permission to use this
operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
525 |
# File 'sig/client.rbs', line 525
def list_tables: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags applied to a specified Amazon S3 Tables resource. Each tag is a label consisting of a key and value pair. Tags can help you organize, track costs for, and control access to resources.
Permissions
: For tables and table buckets, you must have the
s3tables:ListTagsForResource permission to use this operation.
539 |
# File 'sig/client.rbs', line 539
def list_tags_for_resource: (
|
#put_table_bucket_encryption(params = {}) ⇒ Struct
Sets the encryption configuration for a table bucket.
Permissions
: You must have the s3tables:PutTableBucketEncryption permission to
use this operation.
<note markdown="1"> If you choose SSE-KMS encryption you must grant the S3 Tables
maintenance principal access to your KMS key. For more information,
see [Permissions requirements for S3 Tables SSE-KMS encryption][1]
in the *Amazon Simple Storage Service User Guide*.
545 |
# File 'sig/client.rbs', line 545
def put_table_bucket_encryption: (
|
#put_table_bucket_maintenance_configuration(params = {}) ⇒ Struct
Creates a new maintenance configuration or replaces an existing maintenance configuration for a table bucket. For more information, see Amazon S3 table bucket maintenance in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:PutTableBucketMaintenanceConfiguration
permission to use this operation.
555 |
# File 'sig/client.rbs', line 555
def put_table_bucket_maintenance_configuration: (
|
#put_table_bucket_metrics_configuration(params = {}) ⇒ Struct
Sets the metrics configuration for a table bucket.
Permissions
: You must have the s3tables:PutTableBucketMetricsConfiguration
permission to use this operation.
571 |
# File 'sig/client.rbs', line 571
def put_table_bucket_metrics_configuration: (
|
#put_table_bucket_policy(params = {}) ⇒ Struct
Creates a new table bucket policy or replaces an existing table bucket policy for a table bucket. For more information, see Adding a table bucket policy in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:PutTableBucketPolicy permission to use
this operation.
577 |
# File 'sig/client.rbs', line 577
def put_table_bucket_policy: (
|
#put_table_bucket_replication(params = {}) ⇒ Types::PutTableBucketReplicationResponse
Creates or updates the replication configuration for a table bucket. This operation defines how tables in the source bucket are replicated to destination buckets. Replication helps ensure data availability and disaster recovery across regions or accounts.
Permissions
: * You must have the s3tables:PutTableBucketReplication permission
to use this operation. The IAM role specified in the configuration
must have permissions to read from the source bucket and write
permissions to all destination buckets.
* You must also have the following permissions:
* `s3tables:GetTable` permission on the source table.
* `s3tables:ListTables` permission on the bucket containing the
table.
* `s3tables:CreateTable` permission for the destination.
* `s3tables:CreateNamespace` permission for the destination.
* `s3tables:GetTableMaintenanceConfig` permission for the source
bucket.
* `s3tables:PutTableMaintenanceConfig` permission for the
destination bucket.
* You must have `iam:PassRole` permission with condition allowing
roles to be passed to `replication.s3tables.amazonaws.com`.
589 |
# File 'sig/client.rbs', line 589
def put_table_bucket_replication: (
|
#put_table_bucket_storage_class(params = {}) ⇒ Struct
Sets or updates the storage class configuration for a table bucket. This configuration serves as the default storage class for all new tables created in the bucket, allowing you to optimize storage costs at the bucket level.
Permissions
: You must have the s3tables:PutTableBucketStorageClass permission
to use this operation.
608 |
# File 'sig/client.rbs', line 608
def put_table_bucket_storage_class: (
|
#put_table_maintenance_configuration(params = {}) ⇒ Struct
Creates a new maintenance configuration or replaces an existing maintenance configuration for a table. For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:PutTableMaintenanceConfiguration
permission to use this operation.
617 |
# File 'sig/client.rbs', line 617
def put_table_maintenance_configuration: (
|
#put_table_policy(params = {}) ⇒ Struct
Creates a new table policy or replaces an existing table policy for a table. For more information, see Adding a table policy in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:PutTablePolicy permission to use this
operation.
639 |
# File 'sig/client.rbs', line 639
def put_table_policy: (
|
#put_table_record_expiration_configuration(params = {}) ⇒ Struct
Creates or updates the expiration configuration settings for records in a table, including the status of the configuration. If you enable record expiration for a table, records expire and are automatically removed from the table after the number of days that you specify.
Permissions
: You must have the s3tables:PutTableRecordExpirationConfiguration
permission to use this operation.
648 |
# File 'sig/client.rbs', line 648
def put_table_record_expiration_configuration: (
|
#put_table_replication(params = {}) ⇒ Types::PutTableReplicationResponse
Creates or updates the replication configuration for a specific table. This operation allows you to define table-level replication independently of bucket-level replication, providing granular control over which tables are replicated and where.
Permissions
: * You must have the s3tables:PutTableReplication permission to use
this operation. The IAM role specified in the configuration must
have permissions to read from the source table and write to all
destination tables.
* You must also have the following permissions:
* `s3tables:GetTable` permission on the source table being
replicated.
* `s3tables:CreateTable` permission for the destination.
* `s3tables:CreateNamespace` permission for the destination.
* `s3tables:GetTableMaintenanceConfig` permission for the source
table.
* `s3tables:PutTableMaintenanceConfig` permission for the
destination table.
* You must have `iam:PassRole` permission with condition allowing
roles to be passed to `replication.s3tables.amazonaws.com`.
665 |
# File 'sig/client.rbs', line 665
def put_table_replication: (
|
#rename_table(params = {}) ⇒ Struct
Renames a table or a namespace. For more information, see S3 Tables in the Amazon Simple Storage Service User Guide.
Permissions
: You must have the s3tables:RenameTable permission to use this
operation.
684 |
# File 'sig/client.rbs', line 684
def rename_table: (
|
#tag_resource(params = {}) ⇒ Struct
Applies one or more user-defined tags to an Amazon S3 Tables resource or updates existing tags. Each tag is a label consisting of a key and value pair. Tags can help you organize, track costs for, and control access to your resources. You can add up to 50 tags for each S3 resource.
Permissions
: For tables and table buckets, you must have the
s3tables:TagResource permission to use this operation.
698 |
# File 'sig/client.rbs', line 698
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the specified user-defined tags from an Amazon S3 Tables resource. You can pass one or more tag keys.
Permissions
: For tables and table buckets, you must have the
s3tables:UntagResource permission to use this operation.
708 |
# File 'sig/client.rbs', line 708
def untag_resource: (
|
#update_table_metadata_location(params = {}) ⇒ Types::UpdateTableMetadataLocationResponse
Updates the metadata location for a table. The metadata location of a
table must be an S3 URI that begins with the table's warehouse
location. The metadata location for an Apache Iceberg table must end
with .metadata.json, or if the metadata file is Gzip-compressed,
.metadata.json.gz.
Permissions
: You must have the s3tables:UpdateTableMetadataLocation permission
to use this operation.
723 |
# File 'sig/client.rbs', line 723
def update_table_metadata_location: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2983 2984 2985 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2983 def waiter_names [] end |