Class: Aws::S3Tables::Types::IcebergMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Tables::Types::IcebergMetadata
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3tables/types.rb
Overview
Contains details about the metadata for an Iceberg table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#partition_spec ⇒ Types::IcebergPartitionSpec
The partition specification for the Iceberg table.
-
#properties ⇒ Hash<String,String>
A map of custom configuration properties for the Iceberg table.
-
#schema ⇒ Types::IcebergSchema
The schema for an Iceberg table.
-
#schema_v2 ⇒ Types::IcebergSchemaV2
The schema for an Iceberg table using the V2 format.
-
#write_order ⇒ Types::IcebergSortOrder
The sort order for the Iceberg table.
Instance Attribute Details
#partition_spec ⇒ Types::IcebergPartitionSpec
The partition specification for the Iceberg table. Partitioning organizes data into separate files based on the values of one or more fields, which can improve query performance by reducing the amount of data scanned. Each partition field applies a transform (such as identity, year, month, or bucket) to a single field.
1244 1245 1246 1247 1248 1249 1250 1251 1252 |
# File 'lib/aws-sdk-s3tables/types.rb', line 1244 class IcebergMetadata < Struct.new( :schema, :schema_v2, :partition_spec, :write_order, :properties) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Hash<String,String>
A map of custom configuration properties for the Iceberg table.
1244 1245 1246 1247 1248 1249 1250 1251 1252 |
# File 'lib/aws-sdk-s3tables/types.rb', line 1244 class IcebergMetadata < Struct.new( :schema, :schema_v2, :partition_spec, :write_order, :properties) SENSITIVE = [] include Aws::Structure end |
#schema ⇒ Types::IcebergSchema
The schema for an Iceberg table. Use this property to define table schemas with primitive types only. For schemas that include nested or complex types such as ‘struct`, `list`, or `map`, use `schemaV2` instead.
1244 1245 1246 1247 1248 1249 1250 1251 1252 |
# File 'lib/aws-sdk-s3tables/types.rb', line 1244 class IcebergMetadata < Struct.new( :schema, :schema_v2, :partition_spec, :write_order, :properties) SENSITIVE = [] include Aws::Structure end |
#schema_v2 ⇒ Types::IcebergSchemaV2
The schema for an Iceberg table using the V2 format. Use this property to define table schemas that include nested or complex data types such as ‘struct`, `list`, or `map`, in addition to primitive types. For schemas with only primitive types, you can use either `schema` or `schemaV2`.
1244 1245 1246 1247 1248 1249 1250 1251 1252 |
# File 'lib/aws-sdk-s3tables/types.rb', line 1244 class IcebergMetadata < Struct.new( :schema, :schema_v2, :partition_spec, :write_order, :properties) SENSITIVE = [] include Aws::Structure end |
#write_order ⇒ Types::IcebergSortOrder
The sort order for the Iceberg table. Sort order defines how data is sorted within data files, which can improve query performance by enabling more efficient data skipping and filtering.
1244 1245 1246 1247 1248 1249 1250 1251 1252 |
# File 'lib/aws-sdk-s3tables/types.rb', line 1244 class IcebergMetadata < Struct.new( :schema, :schema_v2, :partition_spec, :write_order, :properties) SENSITIVE = [] include Aws::Structure end |