Class: Aws::S3Tables::Types::IcebergPartitionField

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3tables/types.rb

Overview

Defines a single partition field in an Iceberg partition specification.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_idInteger

An optional unique identifier for this partition field. If not specified, S3 Tables automatically assigns a field ID.

Returns:

  • (Integer)


1285
1286
1287
1288
1289
1290
1291
1292
# File 'lib/aws-sdk-s3tables/types.rb', line 1285

class IcebergPartitionField < Struct.new(
  :source_id,
  :transform,
  :name,
  :field_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name for this partition field. This name is used in the partitioned file paths.

Returns:

  • (String)


1285
1286
1287
1288
1289
1290
1291
1292
# File 'lib/aws-sdk-s3tables/types.rb', line 1285

class IcebergPartitionField < Struct.new(
  :source_id,
  :transform,
  :name,
  :field_id)
  SENSITIVE = []
  include Aws::Structure
end

#source_idInteger

The ID of the source schema field to partition by. This must reference a valid field ID from the table schema.

Returns:

  • (Integer)


1285
1286
1287
1288
1289
1290
1291
1292
# File 'lib/aws-sdk-s3tables/types.rb', line 1285

class IcebergPartitionField < Struct.new(
  :source_id,
  :transform,
  :name,
  :field_id)
  SENSITIVE = []
  include Aws::Structure
end

#transformString

The partition transform to apply to the source field. Supported transforms include ‘identity`, `year`, `month`, `day`, `hour`, `bucket`, and `truncate`. For more information, see the [Apache Iceberg partition transforms documentation].

[1]: iceberg.apache.org/spec/#partition-transforms

Returns:

  • (String)


1285
1286
1287
1288
1289
1290
1291
1292
# File 'lib/aws-sdk-s3tables/types.rb', line 1285

class IcebergPartitionField < Struct.new(
  :source_id,
  :transform,
  :name,
  :field_id)
  SENSITIVE = []
  include Aws::Structure
end