Class: Aws::S3Tables::Types::IcebergPartitionSpec
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Tables::Types::IcebergPartitionSpec
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3tables/types.rb
Overview
Defines how data in an Iceberg table is partitioned. Partitioning helps optimize query performance by organizing data into separate files based on field values. Each partition field specifies a transform to apply to a source field.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fields ⇒ Array<Types::IcebergPartitionField>
The list of partition fields that define how the table data is partitioned.
-
#spec_id ⇒ Integer
The unique identifier for this partition specification.
Instance Attribute Details
#fields ⇒ Array<Types::IcebergPartitionField>
The list of partition fields that define how the table data is partitioned. Each field specifies a source field and a transform to apply. This field is required if ‘partitionSpec` is provided.
1312 1313 1314 1315 1316 1317 |
# File 'lib/aws-sdk-s3tables/types.rb', line 1312 class IcebergPartitionSpec < Struct.new( :fields, :spec_id) SENSITIVE = [] include Aws::Structure end |
#spec_id ⇒ Integer
The unique identifier for this partition specification. If not specified, defaults to ‘0`.
1312 1313 1314 1315 1316 1317 |
# File 'lib/aws-sdk-s3tables/types.rb', line 1312 class IcebergPartitionSpec < Struct.new( :fields, :spec_id) SENSITIVE = [] include Aws::Structure end |