Class: Aws::S3Tables::Types::PutTableBucketStorageClassRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3tables/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#storage_class_configurationTypes::StorageClassConfiguration

The storage class configuration to apply to the table bucket. This configuration will serve as the default for new tables created in this bucket.



1906
1907
1908
1909
1910
1911
# File 'lib/aws-sdk-s3tables/types.rb', line 1906

class PutTableBucketStorageClassRequest < Struct.new(
  :table_bucket_arn,
  :storage_class_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#table_bucket_arnString

The Amazon Resource Name (ARN) of the table bucket.

Returns:

  • (String)


1906
1907
1908
1909
1910
1911
# File 'lib/aws-sdk-s3tables/types.rb', line 1906

class PutTableBucketStorageClassRequest < Struct.new(
  :table_bucket_arn,
  :storage_class_configuration)
  SENSITIVE = []
  include Aws::Structure
end