Class: Aws::S3Tables::Types::ReplicationInformation

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3tables/types.rb

Overview

Contains information about the source of a replicated table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#source_table_arnString

The Amazon Resource Name (ARN) of the source table from which this table is replicated.

Returns:

  • (String)


2134
2135
2136
2137
2138
# File 'lib/aws-sdk-s3tables/types.rb', line 2134

class ReplicationInformation < Struct.new(
  :source_table_arn)
  SENSITIVE = []
  include Aws::Structure
end