Class: Aws::S3Tables::Types::SchemaV2Field

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3tables/types.rb

Overview

Contains details about a schema field in the V2 format. This field format supports nested and complex data types such as ‘struct`, `list`, and `map`, in addition to primitive types.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#docString

An optional description of the field.

Returns:

  • (String)


2220
2221
2222
2223
2224
2225
2226
2227
2228
# File 'lib/aws-sdk-s3tables/types.rb', line 2220

class SchemaV2Field < Struct.new(
  :id,
  :name,
  :type,
  :required,
  :doc)
  SENSITIVE = []
  include Aws::Structure
end

#idInteger

The unique identifier for the schema field. Field IDs are used by Apache Iceberg to track schema evolution and maintain compatibility across schema changes.

Returns:

  • (Integer)


2220
2221
2222
2223
2224
2225
2226
2227
2228
# File 'lib/aws-sdk-s3tables/types.rb', line 2220

class SchemaV2Field < Struct.new(
  :id,
  :name,
  :type,
  :required,
  :doc)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the field.

Returns:

  • (String)


2220
2221
2222
2223
2224
2225
2226
2227
2228
# File 'lib/aws-sdk-s3tables/types.rb', line 2220

class SchemaV2Field < Struct.new(
  :id,
  :name,
  :type,
  :required,
  :doc)
  SENSITIVE = []
  include Aws::Structure
end

#requiredBoolean

A Boolean value that specifies whether values are required for each row in this field. If this is ‘true`, the field does not allow null values.

Returns:

  • (Boolean)


2220
2221
2222
2223
2224
2225
2226
2227
2228
# File 'lib/aws-sdk-s3tables/types.rb', line 2220

class SchemaV2Field < Struct.new(
  :id,
  :name,
  :type,
  :required,
  :doc)
  SENSITIVE = []
  include Aws::Structure
end

#typeHash, ...

The data type of the field. This can be a primitive type string such as ‘boolean`, `int`, `long`, `float`, `double`, `string`, `binary`, `date`, `timestamp`, or `timestamptz`, or a complex type represented as a JSON object for nested types such as `struct`, `list`, or `map`. For more information, see the [Apache Iceberg schemas and data types documentation].

[1]: iceberg.apache.org/spec/#schemas-and-data-types

Returns:

  • (Hash, Array, String, Numeric, Boolean)


2220
2221
2222
2223
2224
2225
2226
2227
2228
# File 'lib/aws-sdk-s3tables/types.rb', line 2220

class SchemaV2Field < Struct.new(
  :id,
  :name,
  :type,
  :required,
  :doc)
  SENSITIVE = []
  include Aws::Structure
end