Class: Aws::S3Tables::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::S3Tables::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-s3tables/client.rb
Overview
An API client for S3Tables. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::S3Tables::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_namespace(params = {}) ⇒ Types::CreateNamespaceResponse
Creates a namespace.
-
#create_table(params = {}) ⇒ Types::CreateTableResponse
Creates a new table associated with the given namespace in a table bucket.
-
#create_table_bucket(params = {}) ⇒ Types::CreateTableBucketResponse
Creates a table bucket.
-
#delete_namespace(params = {}) ⇒ Struct
Deletes a namespace.
-
#delete_table(params = {}) ⇒ Struct
Deletes a table.
-
#delete_table_bucket(params = {}) ⇒ Struct
Deletes a table bucket.
-
#delete_table_bucket_encryption(params = {}) ⇒ Struct
Deletes the encryption configuration for a table bucket.
-
#delete_table_bucket_metrics_configuration(params = {}) ⇒ Struct
Deletes the metrics configuration for a table bucket.
-
#delete_table_bucket_policy(params = {}) ⇒ Struct
Deletes a table bucket policy.
-
#delete_table_bucket_replication(params = {}) ⇒ Struct
Deletes the replication configuration for a table bucket.
-
#delete_table_policy(params = {}) ⇒ Struct
Deletes a table policy.
-
#delete_table_replication(params = {}) ⇒ Struct
Deletes the replication configuration for a specific table.
-
#get_namespace(params = {}) ⇒ Types::GetNamespaceResponse
Gets details about a namespace.
-
#get_table(params = {}) ⇒ Types::GetTableResponse
Gets details about a table.
-
#get_table_bucket(params = {}) ⇒ Types::GetTableBucketResponse
Gets details on a table bucket.
-
#get_table_bucket_encryption(params = {}) ⇒ Types::GetTableBucketEncryptionResponse
Gets the encryption configuration for a table bucket.
-
#get_table_bucket_maintenance_configuration(params = {}) ⇒ Types::GetTableBucketMaintenanceConfigurationResponse
Gets details about a maintenance configuration for a given table bucket.
-
#get_table_bucket_metrics_configuration(params = {}) ⇒ Types::GetTableBucketMetricsConfigurationResponse
Gets the metrics configuration for a table bucket.
-
#get_table_bucket_policy(params = {}) ⇒ Types::GetTableBucketPolicyResponse
Gets details about a table bucket policy.
-
#get_table_bucket_replication(params = {}) ⇒ Types::GetTableBucketReplicationResponse
Retrieves the replication configuration for a table bucket.This operation returns the IAM role, ‘versionToken`, and replication rules that define how tables in this bucket are replicated to other buckets.
-
#get_table_bucket_storage_class(params = {}) ⇒ Types::GetTableBucketStorageClassResponse
Retrieves the storage class configuration for a specific table.
-
#get_table_encryption(params = {}) ⇒ Types::GetTableEncryptionResponse
Gets the encryption configuration for a table.
-
#get_table_maintenance_configuration(params = {}) ⇒ Types::GetTableMaintenanceConfigurationResponse
Gets details about the maintenance configuration of a table.
-
#get_table_maintenance_job_status(params = {}) ⇒ Types::GetTableMaintenanceJobStatusResponse
Gets the status of a maintenance job for a table.
-
#get_table_metadata_location(params = {}) ⇒ Types::GetTableMetadataLocationResponse
Gets the location of the table metadata.
-
#get_table_policy(params = {}) ⇒ Types::GetTablePolicyResponse
Gets details about a table policy.
-
#get_table_record_expiration_configuration(params = {}) ⇒ Types::GetTableRecordExpirationConfigurationResponse
Retrieves the expiration configuration settings for records in a table, and the status of the configuration.
-
#get_table_record_expiration_job_status(params = {}) ⇒ Types::GetTableRecordExpirationJobStatusResponse
Retrieves the status, metrics, and details of the latest record expiration job for a table.
-
#get_table_replication(params = {}) ⇒ Types::GetTableReplicationResponse
Retrieves the replication configuration for a specific table.
-
#get_table_replication_status(params = {}) ⇒ Types::GetTableReplicationStatusResponse
Retrieves the replication status for a table, including the status of replication to each destination.
-
#get_table_storage_class(params = {}) ⇒ Types::GetTableStorageClassResponse
Retrieves the storage class configuration for a specific table.
-
#list_namespaces(params = {}) ⇒ Types::ListNamespacesResponse
Lists the namespaces within a table bucket.
-
#list_table_buckets(params = {}) ⇒ Types::ListTableBucketsResponse
Lists table buckets for your account.
-
#list_tables(params = {}) ⇒ Types::ListTablesResponse
List tables in the given table bucket.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags applied to a specified Amazon S3 Tables resource.
-
#put_table_bucket_encryption(params = {}) ⇒ Struct
Sets the encryption configuration for a table bucket.
-
#put_table_bucket_maintenance_configuration(params = {}) ⇒ Struct
Creates a new maintenance configuration or replaces an existing maintenance configuration for a table bucket.
-
#put_table_bucket_metrics_configuration(params = {}) ⇒ Struct
Sets the metrics configuration for a table bucket.
-
#put_table_bucket_policy(params = {}) ⇒ Struct
Creates a new table bucket policy or replaces an existing table bucket policy for a table bucket.
-
#put_table_bucket_replication(params = {}) ⇒ Types::PutTableBucketReplicationResponse
Creates or updates the replication configuration for a table bucket.
-
#put_table_bucket_storage_class(params = {}) ⇒ Struct
Sets or updates the storage class configuration for a table bucket.
-
#put_table_maintenance_configuration(params = {}) ⇒ Struct
Creates a new maintenance configuration or replaces an existing maintenance configuration for a table.
-
#put_table_policy(params = {}) ⇒ Struct
Creates a new table policy or replaces an existing table policy for a table.
-
#put_table_record_expiration_configuration(params = {}) ⇒ Struct
Creates or updates the expiration configuration settings for records in a table, including the status of the configuration.
-
#put_table_replication(params = {}) ⇒ Types::PutTableReplicationResponse
Creates or updates the replication configuration for a specific table.
-
#rename_table(params = {}) ⇒ Struct
Renames a table or a namespace.
-
#tag_resource(params = {}) ⇒ Struct
Applies one or more user-defined tags to an Amazon S3 Tables resource or updates existing tags.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified user-defined tags from an Amazon S3 Tables resource.
-
#update_table_metadata_location(params = {}) ⇒ Types::UpdateTableMetadataLocationResponse
Updates the metadata location for a table.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-s3tables/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2992 2993 2994 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2992 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2995 2996 2997 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2995 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2965 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::S3Tables') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-s3tables' context[:gem_version] = '1.30.0' Seahorse::Client::Request.new(handlers, context) end |
#create_namespace(params = {}) ⇒ Types::CreateNamespaceResponse
Creates a namespace. A namespace is a logical grouping of tables within your table bucket, which you can use to organize tables. For more information, see [Create a namespace] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:CreateNamespace` permission to use this
operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-namespace-create.html
522 523 524 525 |
# File 'lib/aws-sdk-s3tables/client.rb', line 522 def create_namespace(params = {}, = {}) req = build_request(:create_namespace, params) req.send_request() end |
#create_table(params = {}) ⇒ Types::CreateTableResponse
Creates a new table associated with the given namespace in a table bucket. For more information, see [Creating an Amazon S3 table] in the *Amazon Simple Storage Service User Guide*.
Permissions : * You must have the ‘s3tables:CreateTable` permission to use this
operation.
* If you use this operation with the optional `metadata` request
parameter you must have the `s3tables:PutTableData` permission.
* If you use this operation with the optional
`encryptionConfiguration` request parameter you must have the
`s3tables:PutTableEncryption` permission.
* If you use this operation with the `storageClassConfiguration`
request parameter, you must have the
`s3tables:PutTableStorageClass` permission.
* To create a table with tags, you must have the
`s3tables:TagResource` permission in addition to
`s3tables:CreateTable` permission.
<note markdown="1"> Additionally, If you choose SSE-KMS encryption you must grant the S3
Tables maintenance principal access to your KMS key. For more
information, see [Permissions requirements for S3 Tables SSE-KMS
encryption][2].
</note>
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-create.html [2]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-kms-permissions.html
702 703 704 705 |
# File 'lib/aws-sdk-s3tables/client.rb', line 702 def create_table(params = {}, = {}) req = build_request(:create_table, params) req.send_request() end |
#create_table_bucket(params = {}) ⇒ Types::CreateTableBucketResponse
Creates a table bucket. For more information, see [Creating a table bucket] in the *Amazon Simple Storage Service User Guide*.
Permissions : * You must have the ‘s3tables:CreateTableBucket` permission to use
this operation.
* If you use this operation with the optional
`encryptionConfiguration` parameter you must have the
`s3tables:PutTableBucketEncryption` permission.
* If you use this operation with the `storageClassConfiguration`
request parameter, you must have the
`s3tables:PutTableBucketStorageClass` permission.
* To create a table bucket with tags, you must have the
`s3tables:TagResource` permission in addition to
`s3tables:CreateTableBucket` permission.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-buckets-create.html
791 792 793 794 |
# File 'lib/aws-sdk-s3tables/client.rb', line 791 def create_table_bucket(params = {}, = {}) req = build_request(:create_table_bucket, params) req.send_request() end |
#delete_namespace(params = {}) ⇒ Struct
Deletes a namespace. For more information, see [Delete a namespace] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:DeleteNamespace` permission to use this
operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-namespace-delete.html
828 829 830 831 |
# File 'lib/aws-sdk-s3tables/client.rb', line 828 def delete_namespace(params = {}, = {}) req = build_request(:delete_namespace, params) req.send_request() end |
#delete_table(params = {}) ⇒ Struct
Deletes a table. For more information, see [Deleting an Amazon S3 table] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:DeleteTable` permission to use this
operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-delete.html
873 874 875 876 |
# File 'lib/aws-sdk-s3tables/client.rb', line 873 def delete_table(params = {}, = {}) req = build_request(:delete_table, params) req.send_request() end |
#delete_table_bucket(params = {}) ⇒ Struct
Deletes a table bucket. For more information, see [Deleting a table bucket] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:DeleteTableBucket` permission to use
this operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-buckets-delete.html
905 906 907 908 |
# File 'lib/aws-sdk-s3tables/client.rb', line 905 def delete_table_bucket(params = {}, = {}) req = build_request(:delete_table_bucket, params) req.send_request() end |
#delete_table_bucket_encryption(params = {}) ⇒ Struct
Deletes the encryption configuration for a table bucket.
Permissions
: You must have the ‘s3tables:DeleteTableBucketEncryption` permission
to use this operation.
932 933 934 935 |
# File 'lib/aws-sdk-s3tables/client.rb', line 932 def delete_table_bucket_encryption(params = {}, = {}) req = build_request(:delete_table_bucket_encryption, params) req.send_request() end |
#delete_table_bucket_metrics_configuration(params = {}) ⇒ Struct
Deletes the metrics configuration for a table bucket.
Permissions
: You must have the ‘s3tables:DeleteTableBucketMetricsConfiguration`
permission to use this operation.
959 960 961 962 |
# File 'lib/aws-sdk-s3tables/client.rb', line 959 def delete_table_bucket_metrics_configuration(params = {}, = {}) req = build_request(:delete_table_bucket_metrics_configuration, params) req.send_request() end |
#delete_table_bucket_policy(params = {}) ⇒ Struct
Deletes a table bucket policy. For more information, see [Deleting a table bucket policy] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:DeleteTableBucketPolicy` permission to
use this operation.
992 993 994 995 |
# File 'lib/aws-sdk-s3tables/client.rb', line 992 def delete_table_bucket_policy(params = {}, = {}) req = build_request(:delete_table_bucket_policy, params) req.send_request() end |
#delete_table_bucket_replication(params = {}) ⇒ Struct
Deletes the replication configuration for a table bucket. After deletion, new table updates will no longer be replicated to destination buckets, though existing replicated tables will remain in destination buckets.
Permissions
: You must have the ‘s3tables:DeleteTableBucketReplication` permission
to use this operation.
1028 1029 1030 1031 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1028 def delete_table_bucket_replication(params = {}, = {}) req = build_request(:delete_table_bucket_replication, params) req.send_request() end |
#delete_table_policy(params = {}) ⇒ Struct
Deletes a table policy. For more information, see [Deleting a table policy] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:DeleteTablePolicy` permission to use
this operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-table-policy.html#table-policy-delete
1069 1070 1071 1072 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1069 def delete_table_policy(params = {}, = {}) req = build_request(:delete_table_policy, params) req.send_request() end |
#delete_table_replication(params = {}) ⇒ Struct
Deletes the replication configuration for a specific table. After deletion, new updates to this table will no longer be replicated to destination tables, though existing replicated copies will remain in destination buckets.
Permissions
: You must have the ‘s3tables:DeleteTableReplication` permission to
use this operation.
1105 1106 1107 1108 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1105 def delete_table_replication(params = {}, = {}) req = build_request(:delete_table_replication, params) req.send_request() end |
#get_namespace(params = {}) ⇒ Types::GetNamespaceResponse
Gets details about a namespace. For more information, see [Table namespaces] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:GetNamespace` permission to use this
operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-namespace.html
1158 1159 1160 1161 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1158 def get_namespace(params = {}, = {}) req = build_request(:get_namespace, params) req.send_request() end |
#get_table(params = {}) ⇒ Types::GetTableResponse
Gets details about a table. For more information, see [S3 Tables] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:GetTable` permission to use this
operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-tables.html
1242 1243 1244 1245 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1242 def get_table(params = {}, = {}) req = build_request(:get_table, params) req.send_request() end |
#get_table_bucket(params = {}) ⇒ Types::GetTableBucketResponse
Gets details on a table bucket. For more information, see [Viewing details about an Amazon S3 table bucket] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:GetTableBucket` permission to use this
operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-buckets-details.html
1291 1292 1293 1294 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1291 def get_table_bucket(params = {}, = {}) req = build_request(:get_table_bucket, params) req.send_request() end |
#get_table_bucket_encryption(params = {}) ⇒ Types::GetTableBucketEncryptionResponse
Gets the encryption configuration for a table bucket.
Permissions
: You must have the ‘s3tables:GetTableBucketEncryption` permission to
use this operation.
1325 1326 1327 1328 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1325 def get_table_bucket_encryption(params = {}, = {}) req = build_request(:get_table_bucket_encryption, params) req.send_request() end |
#get_table_bucket_maintenance_configuration(params = {}) ⇒ Types::GetTableBucketMaintenanceConfigurationResponse
Gets details about a maintenance configuration for a given table bucket. For more information, see [Amazon S3 table bucket maintenance] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:GetTableBucketMaintenanceConfiguration`
permission to use this operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-table-buckets-maintenance.html
1370 1371 1372 1373 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1370 def get_table_bucket_maintenance_configuration(params = {}, = {}) req = build_request(:get_table_bucket_maintenance_configuration, params) req.send_request() end |
#get_table_bucket_metrics_configuration(params = {}) ⇒ Types::GetTableBucketMetricsConfigurationResponse
Gets the metrics configuration for a table bucket.
Permissions
: You must have the ‘s3tables:GetTableBucketMetricsConfiguration`
permission to use this operation.
1405 1406 1407 1408 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1405 def get_table_bucket_metrics_configuration(params = {}, = {}) req = build_request(:get_table_bucket_metrics_configuration, params) req.send_request() end |
#get_table_bucket_policy(params = {}) ⇒ Types::GetTableBucketPolicyResponse
Gets details about a table bucket policy. For more information, see
- Viewing a table bucket policy][1
-
in the *Amazon Simple Storage
Service User Guide*.
Permissions
: You must have the ‘s3tables:GetTableBucketPolicy` permission to use
this operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-bucket-policy.html#table-bucket-policy-get
1444 1445 1446 1447 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1444 def get_table_bucket_policy(params = {}, = {}) req = build_request(:get_table_bucket_policy, params) req.send_request() end |
#get_table_bucket_replication(params = {}) ⇒ Types::GetTableBucketReplicationResponse
Retrieves the replication configuration for a table bucket.This operation returns the IAM role, ‘versionToken`, and replication rules that define how tables in this bucket are replicated to other buckets.
Permissions
: You must have the ‘s3tables:GetTableBucketReplication` permission to
use this operation.
1484 1485 1486 1487 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1484 def get_table_bucket_replication(params = {}, = {}) req = build_request(:get_table_bucket_replication, params) req.send_request() end |
#get_table_bucket_storage_class(params = {}) ⇒ Types::GetTableBucketStorageClassResponse
Retrieves the storage class configuration for a specific table. This allows you to view the storage class settings that apply to an individual table, which may differ from the table bucket’s default configuration.
Permissions
: You must have the ‘s3tables:GetTableBucketStorageClass` permission
to use this operation.
1520 1521 1522 1523 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1520 def get_table_bucket_storage_class(params = {}, = {}) req = build_request(:get_table_bucket_storage_class, params) req.send_request() end |
#get_table_encryption(params = {}) ⇒ Types::GetTableEncryptionResponse
Gets the encryption configuration for a table.
Permissions
: You must have the ‘s3tables:GetTableEncryption` permission to use
this operation.
1563 1564 1565 1566 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1563 def get_table_encryption(params = {}, = {}) req = build_request(:get_table_encryption, params) req.send_request() end |
#get_table_maintenance_configuration(params = {}) ⇒ Types::GetTableMaintenanceConfigurationResponse
Gets details about the maintenance configuration of a table. For more information, see [S3 Tables maintenance] in the *Amazon Simple Storage Service User Guide*.
Permissions : * You must have the ‘s3tables:GetTableMaintenanceConfiguration`
permission to use this operation.
* You must have the `s3tables:GetTableData` permission to use set
the compaction strategy to `sort` or `zorder`.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-maintenance.html
1619 1620 1621 1622 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1619 def get_table_maintenance_configuration(params = {}, = {}) req = build_request(:get_table_maintenance_configuration, params) req.send_request() end |
#get_table_maintenance_job_status(params = {}) ⇒ Types::GetTableMaintenanceJobStatusResponse
Gets the status of a maintenance job for a table. For more information, see [S3 Tables maintenance] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:GetTableMaintenanceJobStatus` permission
to use this operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-maintenance.html
1672 1673 1674 1675 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1672 def get_table_maintenance_job_status(params = {}, = {}) req = build_request(:get_table_maintenance_job_status, params) req.send_request() end |
#get_table_metadata_location(params = {}) ⇒ Types::GetTableMetadataLocationResponse
Gets the location of the table metadata.
Permissions
: You must have the ‘s3tables:GetTableMetadataLocation` permission to
use this operation.
1717 1718 1719 1720 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1717 def (params = {}, = {}) req = build_request(:get_table_metadata_location, params) req.send_request() end |
#get_table_policy(params = {}) ⇒ Types::GetTablePolicyResponse
Gets details about a table policy. For more information, see [Viewing a table policy] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:GetTablePolicy` permission to use this
operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-table-policy.html#table-policy-get
1764 1765 1766 1767 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1764 def get_table_policy(params = {}, = {}) req = build_request(:get_table_policy, params) req.send_request() end |
#get_table_record_expiration_configuration(params = {}) ⇒ Types::GetTableRecordExpirationConfigurationResponse
Retrieves the expiration configuration settings for records in a table, and the status of the configuration. If the status of the configuration is ‘enabled`, records expire and are automatically removed from the table after the specified number of days.
Permissions
: You must have the ‘s3tables:GetTableRecordExpirationConfiguration`
permission to use this operation.
1801 1802 1803 1804 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1801 def get_table_record_expiration_configuration(params = {}, = {}) req = build_request(:get_table_record_expiration_configuration, params) req.send_request() end |
#get_table_record_expiration_job_status(params = {}) ⇒ Types::GetTableRecordExpirationJobStatusResponse
Retrieves the status, metrics, and details of the latest record expiration job for a table. This includes when the job ran, and whether it succeeded or failed. If the job ran successfully, this also includes statistics about the records that were removed.
Permissions
: You must have the ‘s3tables:GetTableRecordExpirationJobStatus`
permission to use this operation.
1845 1846 1847 1848 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1845 def get_table_record_expiration_job_status(params = {}, = {}) req = build_request(:get_table_record_expiration_job_status, params) req.send_request() end |
#get_table_replication(params = {}) ⇒ Types::GetTableReplicationResponse
Retrieves the replication configuration for a specific table.
Permissions
: You must have the ‘s3tables:GetTableReplication` permission to use
this operation.
1883 1884 1885 1886 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1883 def get_table_replication(params = {}, = {}) req = build_request(:get_table_replication, params) req.send_request() end |
#get_table_replication_status(params = {}) ⇒ Types::GetTableReplicationStatusResponse
Retrieves the replication status for a table, including the status of replication to each destination. This operation provides visibility into replication health and progress.
Permissions
: You must have the ‘s3tables:GetTableReplicationStatus` permission to
use this operation.
1926 1927 1928 1929 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1926 def get_table_replication_status(params = {}, = {}) req = build_request(:get_table_replication_status, params) req.send_request() end |
#get_table_storage_class(params = {}) ⇒ Types::GetTableStorageClassResponse
Retrieves the storage class configuration for a specific table. This allows you to view the storage class settings that apply to an individual table, which may differ from the table bucket’s default configuration.
Permissions
: You must have the ‘s3tables:GetTableStorageClass` permission to use
this operation.
1971 1972 1973 1974 |
# File 'lib/aws-sdk-s3tables/client.rb', line 1971 def get_table_storage_class(params = {}, = {}) req = build_request(:get_table_storage_class, params) req.send_request() end |
#list_namespaces(params = {}) ⇒ Types::ListNamespacesResponse
Lists the namespaces within a table bucket. For more information, see
- Table namespaces][1
-
in the *Amazon Simple Storage Service User
Guide*.
Permissions
: You must have the ‘s3tables:ListNamespaces` permission to use this
operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-namespace.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2036 2037 2038 2039 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2036 def list_namespaces(params = {}, = {}) req = build_request(:list_namespaces, params) req.send_request() end |
#list_table_buckets(params = {}) ⇒ Types::ListTableBucketsResponse
Lists table buckets for your account. For more information, see [S3 Table buckets] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:ListTableBuckets` permission to use this
operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-buckets.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2099 2100 2101 2102 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2099 def list_table_buckets(params = {}, = {}) req = build_request(:list_table_buckets, params) req.send_request() end |
#list_tables(params = {}) ⇒ Types::ListTablesResponse
List tables in the given table bucket. For more information, see [S3 Tables] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:ListTables` permission to use this
operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-tables.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2170 2171 2172 2173 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2170 def list_tables(params = {}, = {}) req = build_request(:list_tables, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags applied to a specified Amazon S3 Tables resource. Each tag is a label consisting of a key and value pair. Tags can help you organize, track costs for, and control access to resources.
<note markdown=“1”> For a list of S3 resources that support tagging, see [Managing tags for Amazon S3 resources].
</note>
Permissions
: For tables and table buckets, you must have the
`s3tables:ListTagsForResource` permission to use this operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/tagging.html#manage-tags
2223 2224 2225 2226 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2223 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_table_bucket_encryption(params = {}) ⇒ Struct
Sets the encryption configuration for a table bucket.
Permissions
: You must have the ‘s3tables:PutTableBucketEncryption` permission to
use this operation.
<note markdown="1"> If you choose SSE-KMS encryption you must grant the S3 Tables
maintenance principal access to your KMS key. For more information,
see [Permissions requirements for S3 Tables SSE-KMS encryption][1]
in the *Amazon Simple Storage Service User Guide*.
</note>
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-kms-permissions.html
2268 2269 2270 2271 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2268 def put_table_bucket_encryption(params = {}, = {}) req = build_request(:put_table_bucket_encryption, params) req.send_request() end |
#put_table_bucket_maintenance_configuration(params = {}) ⇒ Struct
Creates a new maintenance configuration or replaces an existing maintenance configuration for a table bucket. For more information, see [Amazon S3 table bucket maintenance] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:PutTableBucketMaintenanceConfiguration`
permission to use this operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-table-buckets-maintenance.html
2320 2321 2322 2323 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2320 def put_table_bucket_maintenance_configuration(params = {}, = {}) req = build_request(:put_table_bucket_maintenance_configuration, params) req.send_request() end |
#put_table_bucket_metrics_configuration(params = {}) ⇒ Struct
Sets the metrics configuration for a table bucket.
Permissions
: You must have the ‘s3tables:PutTableBucketMetricsConfiguration`
permission to use this operation.
2347 2348 2349 2350 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2347 def put_table_bucket_metrics_configuration(params = {}, = {}) req = build_request(:put_table_bucket_metrics_configuration, params) req.send_request() end |
#put_table_bucket_policy(params = {}) ⇒ Struct
Creates a new table bucket policy or replaces an existing table bucket policy for a table bucket. For more information, see [Adding a table bucket policy] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:PutTableBucketPolicy` permission to use
this operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-bucket-policy.html#table-bucket-policy-add
2384 2385 2386 2387 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2384 def put_table_bucket_policy(params = {}, = {}) req = build_request(:put_table_bucket_policy, params) req.send_request() end |
#put_table_bucket_replication(params = {}) ⇒ Types::PutTableBucketReplicationResponse
Creates or updates the replication configuration for a table bucket. This operation defines how tables in the source bucket are replicated to destination buckets. Replication helps ensure data availability and disaster recovery across regions or accounts.
Permissions : * You must have the ‘s3tables:PutTableBucketReplication` permission
to use this operation. The IAM role specified in the configuration
must have permissions to read from the source bucket and write
permissions to all destination buckets.
* You must also have the following permissions:
* `s3tables:GetTable` permission on the source table.
* `s3tables:ListTables` permission on the bucket containing the
table.
* `s3tables:CreateTable` permission for the destination.
* `s3tables:CreateNamespace` permission for the destination.
* `s3tables:GetTableMaintenanceConfig` permission for the source
bucket.
* `s3tables:PutTableMaintenanceConfig` permission for the
destination bucket.
* You must have `iam:PassRole` permission with condition allowing
roles to be passed to `replication.s3tables.amazonaws.com`.
2464 2465 2466 2467 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2464 def put_table_bucket_replication(params = {}, = {}) req = build_request(:put_table_bucket_replication, params) req.send_request() end |
#put_table_bucket_storage_class(params = {}) ⇒ Struct
Sets or updates the storage class configuration for a table bucket. This configuration serves as the default storage class for all new tables created in the bucket, allowing you to optimize storage costs at the bucket level.
Permissions
: You must have the ‘s3tables:PutTableBucketStorageClass` permission
to use this operation.
2502 2503 2504 2505 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2502 def put_table_bucket_storage_class(params = {}, = {}) req = build_request(:put_table_bucket_storage_class, params) req.send_request() end |
#put_table_maintenance_configuration(params = {}) ⇒ Struct
Creates a new maintenance configuration or replaces an existing maintenance configuration for a table. For more information, see [S3 Tables maintenance] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:PutTableMaintenanceConfiguration`
permission to use this operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-maintenance.html
2565 2566 2567 2568 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2565 def put_table_maintenance_configuration(params = {}, = {}) req = build_request(:put_table_maintenance_configuration, params) req.send_request() end |
#put_table_policy(params = {}) ⇒ Struct
Creates a new table policy or replaces an existing table policy for a table. For more information, see [Adding a table policy] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:PutTablePolicy` permission to use this
operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-table-policy.html#table-policy-add
2611 2612 2613 2614 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2611 def put_table_policy(params = {}, = {}) req = build_request(:put_table_policy, params) req.send_request() end |
#put_table_record_expiration_configuration(params = {}) ⇒ Struct
Creates or updates the expiration configuration settings for records in a table, including the status of the configuration. If you enable record expiration for a table, records expire and are automatically removed from the table after the number of days that you specify.
Permissions
: You must have the ‘s3tables:PutTableRecordExpirationConfiguration`
permission to use this operation.
2651 2652 2653 2654 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2651 def put_table_record_expiration_configuration(params = {}, = {}) req = build_request(:put_table_record_expiration_configuration, params) req.send_request() end |
#put_table_replication(params = {}) ⇒ Types::PutTableReplicationResponse
Creates or updates the replication configuration for a specific table. This operation allows you to define table-level replication independently of bucket-level replication, providing granular control over which tables are replicated and where.
Permissions : * You must have the ‘s3tables:PutTableReplication` permission to use
this operation. The IAM role specified in the configuration must
have permissions to read from the source table and write to all
destination tables.
* You must also have the following permissions:
* `s3tables:GetTable` permission on the source table being
replicated.
* `s3tables:CreateTable` permission for the destination.
* `s3tables:CreateNamespace` permission for the destination.
* `s3tables:GetTableMaintenanceConfig` permission for the source
table.
* `s3tables:PutTableMaintenanceConfig` permission for the
destination table.
* You must have `iam:PassRole` permission with condition allowing
roles to be passed to `replication.s3tables.amazonaws.com`.
2729 2730 2731 2732 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2729 def put_table_replication(params = {}, = {}) req = build_request(:put_table_replication, params) req.send_request() end |
#rename_table(params = {}) ⇒ Struct
Renames a table or a namespace. For more information, see [S3 Tables] in the *Amazon Simple Storage Service User Guide*.
Permissions
: You must have the ‘s3tables:RenameTable` permission to use this
operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-tables.html
2781 2782 2783 2784 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2781 def rename_table(params = {}, = {}) req = build_request(:rename_table, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Applies one or more user-defined tags to an Amazon S3 Tables resource or updates existing tags. Each tag is a label consisting of a key and value pair. Tags can help you organize, track costs for, and control access to your resources. You can add up to 50 tags for each S3 resource.
<note markdown=“1”> For a list of S3 resources that support tagging, see [Managing tags for Amazon S3 resources].
</note>
Permissions
: For tables and table buckets, you must have the
`s3tables:TagResource` permission to use this operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/tagging.html#manage-tags
2840 2841 2842 2843 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2840 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the specified user-defined tags from an Amazon S3 Tables resource. You can pass one or more tag keys.
<note markdown=“1”> For a list of S3 resources that support tagging, see [Managing tags for Amazon S3 resources].
</note>
Permissions
: For tables and table buckets, you must have the
`s3tables:UntagResource` permission to use this operation.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/tagging.html#manage-tags
2894 2895 2896 2897 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2894 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_table_metadata_location(params = {}) ⇒ Types::UpdateTableMetadataLocationResponse
Updates the metadata location for a table. The metadata location of a table must be an S3 URI that begins with the table’s warehouse location. The metadata location for an Apache Iceberg table must end with ‘.metadata.json`, or if the metadata file is Gzip-compressed, `.metadata.json.gz`.
Permissions
: You must have the ‘s3tables:UpdateTableMetadataLocation` permission
to use this operation.
2956 2957 2958 2959 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2956 def (params = {}, = {}) req = build_request(:update_table_metadata_location, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2985 2986 2987 |
# File 'lib/aws-sdk-s3tables/client.rb', line 2985 def waiter_names [] end |