Class: Aws::S3Tables::Types::IcebergPartitionField
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Tables::Types::IcebergPartitionField
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3tables/types.rb
Overview
Defines a single partition field in an Iceberg partition specification.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_id ⇒ Integer
An optional unique identifier for this partition field.
-
#name ⇒ String
The name for this partition field.
-
#source_id ⇒ Integer
The ID of the source schema field to partition by.
-
#transform ⇒ String
The partition transform to apply to the source field.
Instance Attribute Details
#field_id ⇒ Integer
An optional unique identifier for this partition field. If not specified, S3 Tables automatically assigns a field ID.
1285 1286 1287 1288 1289 1290 1291 1292 |
# File 'lib/aws-sdk-s3tables/types.rb', line 1285 class IcebergPartitionField < Struct.new( :source_id, :transform, :name, :field_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name for this partition field. This name is used in the partitioned file paths.
1285 1286 1287 1288 1289 1290 1291 1292 |
# File 'lib/aws-sdk-s3tables/types.rb', line 1285 class IcebergPartitionField < Struct.new( :source_id, :transform, :name, :field_id) SENSITIVE = [] include Aws::Structure end |
#source_id ⇒ Integer
The ID of the source schema field to partition by. This must reference a valid field ID from the table schema.
1285 1286 1287 1288 1289 1290 1291 1292 |
# File 'lib/aws-sdk-s3tables/types.rb', line 1285 class IcebergPartitionField < Struct.new( :source_id, :transform, :name, :field_id) SENSITIVE = [] include Aws::Structure end |
#transform ⇒ String
The partition transform to apply to the source field. Supported transforms include ‘identity`, `year`, `month`, `day`, `hour`, `bucket`, and `truncate`. For more information, see the [Apache Iceberg partition transforms documentation].
1285 1286 1287 1288 1289 1290 1291 1292 |
# File 'lib/aws-sdk-s3tables/types.rb', line 1285 class IcebergPartitionField < Struct.new( :source_id, :transform, :name, :field_id) SENSITIVE = [] include Aws::Structure end |