Class: Aws::S3Tables::Types::IcebergSchemaV2
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Tables::Types::IcebergSchemaV2
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3tables/types.rb
Overview
Contains details about the schema for an Iceberg table using the V2 format. This schema format supports nested and complex data types such as ‘struct`, `list`, and `map`, in addition to primitive types.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fields ⇒ Array<Types::SchemaV2Field>
The schema fields for the table.
-
#identifier_field_ids ⇒ Array<Integer>
A list of field IDs that are used as the identifier fields for the table.
-
#schema_id ⇒ Integer
An optional unique identifier for the schema.
-
#type ⇒ String
The type of the top-level schema, which is always a ‘struct` type as defined in the [Apache Iceberg specification].
Instance Attribute Details
#fields ⇒ Array<Types::SchemaV2Field>
The schema fields for the table. Each field defines a column in the table, including its name, type, and whether it is required.
1364 1365 1366 1367 1368 1369 1370 1371 |
# File 'lib/aws-sdk-s3tables/types.rb', line 1364 class IcebergSchemaV2 < Struct.new( :type, :fields, :schema_id, :identifier_field_ids) SENSITIVE = [] include Aws::Structure end |
#identifier_field_ids ⇒ Array<Integer>
A list of field IDs that are used as the identifier fields for the table. Identifier fields uniquely identify a row in the table.
1364 1365 1366 1367 1368 1369 1370 1371 |
# File 'lib/aws-sdk-s3tables/types.rb', line 1364 class IcebergSchemaV2 < Struct.new( :type, :fields, :schema_id, :identifier_field_ids) SENSITIVE = [] include Aws::Structure end |
#schema_id ⇒ Integer
An optional unique identifier for the schema. Schema IDs are used by Apache Iceberg to track schema evolution.
1364 1365 1366 1367 1368 1369 1370 1371 |
# File 'lib/aws-sdk-s3tables/types.rb', line 1364 class IcebergSchemaV2 < Struct.new( :type, :fields, :schema_id, :identifier_field_ids) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the top-level schema, which is always a ‘struct` type as defined in the [Apache Iceberg specification]. This value must be `struct`.
1364 1365 1366 1367 1368 1369 1370 1371 |
# File 'lib/aws-sdk-s3tables/types.rb', line 1364 class IcebergSchemaV2 < Struct.new( :type, :fields, :schema_id, :identifier_field_ids) SENSITIVE = [] include Aws::Structure end |