Class: Aws::S3Tables::Types::StorageClassConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Tables::Types::StorageClassConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3tables/types.rb
Overview
The configuration details for the storage class of tables or table buckets. This allows you to optimize storage costs by selecting the appropriate storage class based on your access patterns and performance requirements.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#storage_class ⇒ String
The storage class for the table or table bucket.
Instance Attribute Details
#storage_class ⇒ String
The storage class for the table or table bucket. Valid values include storage classes optimized for different access patterns and cost profiles.
2243 2244 2245 2246 2247 |
# File 'lib/aws-sdk-s3tables/types.rb', line 2243 class StorageClassConfiguration < Struct.new( :storage_class) SENSITIVE = [] include Aws::Structure end |